@@ -104,9 +104,9 @@ def read_rows_from_batch(query_columns_description: list, dis: DataInputStream)
             row = read_values_from_array(query_columns_description, dis)
             rows.append(row)
         #   if rows become 1000, break it
-            if len(rows) == 1000:
-                _logger.info("Read Batch - Breaking the loop after 1000 records")
-                break
+        #     if len(rows) == 1000:
+        #         _logger.info("Read Batch - Breaking the loop after 1000 records")
+        #         break
         is_row_present = dis.read_byte()
 
     return rows
