@@ -345,13 +345,14 @@ class Cursor(common.DBAPICursor):
             self.fetch_batch()
             if len(self._batch) == 0:
                 return None
-        self.rows_count += len(self._batch)
-        if self.rows_count <= 1000:
-            row = self._batch
-        else:
-            row = None
-            # reset row counter for next query execution
-            self.rows_count = 0
+        # self.rows_count += len(self._batch)
+        # if self.rows_count <= 1000:
+        #     row = self._batch
+        # else:
+        #     row = None
+        #     # reset row counter for next query execution
+        #     self.rows_count = 0
+        row = self._batch
         return row
 
     # def fetchone(self):
